@@ -20,8 +20,7 @@ var rootCmd = &cobra.Command{
 		case flagListLangs:
 			return gat.PrintLanguages(os.Stdout)
 		case flagListFormats:
-			gat.PrintFormats(os.Stdout)
-			return nil
+			return gat.PrintFormats(os.Stdout)
 		case flagListThemes:
 			return gat.PrintThemes(os.Stdout, ist)
 		}
